#include <cstddef>
#include <rumur/Node.h>

namespace rumur {

Node::Node(const location &loc_) : loc(loc_) {}

} // namespace rumur
